Don't indent non-editable nodes
authorAryeh Gregor <AryehGregor+gitcommit@gmail.com>
Mon, 02 May 2011 15:58:53 -0600
changeset 80 5091444fe74e
parent 79 31a92c8d8838
child 81 08585da74e99
Don't indent non-editable nodes
editcommands.html
implementation.js
source.html
--- a/editcommands.html	Mon May 02 15:57:04 2011 -0600
+++ b/editcommands.html	Mon May 02 15:58:53 2011 -0600
@@ -1912,9 +1912,9 @@
   <li>Let <var title="">node list</var> be a list of <a class=external data-anolis-spec=domcore href=http://dvcs.w3.org/hg/domcore/raw-file/tip/Overview.html#concept-node title=concept-node>nodes</a>, initially empty.
 
   <li>For each <a class=external data-anolis-spec=domcore href=http://dvcs.w3.org/hg/domcore/raw-file/tip/Overview.html#concept-node title=concept-node>node</a> <var title="">node</var> <a class=external data-anolis-spec=domrange href=http://html5.org/specs/dom-range.html#contained>contained</a> in <var title="">new range</var>,
-  if <var title="">node</var> can be the <a class=external data-anolis-spec=domcore href=http://dvcs.w3.org/hg/domcore/raw-file/tip/Overview.html#concept-tree-child title=concept-tree-child>child</a> of a <code class=external data-anolis-spec=html title="the blockquote element"><a href=http://www.whatwg.org/html/#the-blockquote-element>blockquote</a></code> and if no
-  <a class=external data-anolis-spec=domcore href=http://dvcs.w3.org/hg/domcore/raw-file/tip/Overview.html#concept-tree-ancestor title=concept-tree-ancestor>ancestor</a> of <var title="">node</var> is in <var title="">node list</var>, append
-  <var title="">node</var> to <var title="">node list</var>.
+  if <var title="">node</var> is <a href=#editable>editable</a> and can be the <a class=external data-anolis-spec=domcore href=http://dvcs.w3.org/hg/domcore/raw-file/tip/Overview.html#concept-tree-child title=concept-tree-child>child</a> of a
+  <code class=external data-anolis-spec=html title="the blockquote element"><a href=http://www.whatwg.org/html/#the-blockquote-element>blockquote</a></code> and if no <a class=external data-anolis-spec=domcore href=http://dvcs.w3.org/hg/domcore/raw-file/tip/Overview.html#concept-tree-ancestor title=concept-tree-ancestor>ancestor</a> of <var title="">node</var> is in <var title="">node
+  list</var>, append <var title="">node</var> to <var title="">node list</var>.
 
   <li><a href=#indent>Indent</a> each member of <var title="">node list</var>.
 </ol>
--- a/source.html	Mon May 02 15:57:04 2011 -0600
+++ b/source.html	Mon May 02 15:58:53 2011 -0600
@@ -1928,9 +1928,9 @@
   <li>Let <var>node list</var> be a list of [[nodes]], initially empty.
 
   <li>For each [[node]] <var>node</var> [[contained]] in <var>new range</var>,
-  if <var>node</var> can be the [[child]] of a [[blockquote]] and if no
-  [[ancestor]] of <var>node</var> is in <var>node list</var>, append
-  <var>node</var> to <var>node list</var>.
+  if <var>node</var> is <span>editable</span> and can be the [[child]] of a
+  [[blockquote]] and if no [[ancestor]] of <var>node</var> is in <var>node
+  list</var>, append <var>node</var> to <var>node list</var>.
 
   <li><span>Indent</span> each member of <var>node list</var>.
 </ol>
--- a/implementation.js	Mon May 02 15:57:04 2011 -0600
+++ b/implementation.js	Mon May 02 15:58:53 2011 -0600
@@ -2114,11 +2114,11 @@
 		// "Let node list be a list of nodes, initially empty."
 		var nodeList = [];
 
 		// "For each node node contained in new range, if node can be the child
 		// of a blockquote and if no ancestor of node is in node list, append
 		// node to node list."
 		for (var node = newRange.startContainer; node != nextNodeDescendants(newRange.endContainer); node = nextNode(node)) {
-			if (!isContained(node, newRange)) {
+			if (!isContained(node, newRange) || !isEditable(node)) {
 				continue;
 			}
 
@@ -2114,11 +2114,11 @@
 		var nodeList = [];
 
-		// "For each node node contained in new range, if node can be the child
-		// of a blockquote and if no ancestor of node is in node list, append
-		// node to node list."
+		// "For each node node contained in new range, if node is editable and
+		// can be the child of a blockquote and if no ancestor of node is in
+		// node list, append node to node list."
 		for (var node = newRange.startContainer; node != nextNodeDescendants(newRange.endContainer); node = nextNode(node)) {